Context

Struct Context 

pub struct Context<D: Demuxer, R: Buffered> {
    pub info: GlobalInfo,
    pub user_private: Option<Arc<dyn Any + Send + Sync>>,
    /* private fields */
}
Auxiliary structure to encapsulate a demuxer object and its additional data.

Fields

info: GlobalInfo

Global media file information.

user_private: Option<Arc<dyn Any + Send + Sync>>

User private data.

This data cannot be cloned.

Implementations

Source

impl<D: Demuxer, R: Buffered> Context<D, R>

pub fn new(demuxer: D, reader: R) -> Self

Creates a new Context instance.

pub fn demuxer(&self) -> &D

Returns the underlying demuxer.

pub fn read_headers(&mut self) -> Result<()>

Reads stream headers and global information from a data source.

pub fn read_event(&mut self) -> Result<Event>

Reads an event from a data source.