Descriptor

Trait Descriptor 

pub trait Descriptor {
    type OutputDemuxer: Demuxer;

    // Required methods
    fn create(&self) -> Self::OutputDemuxer;
    fn describe(&self) -> &Descr;
    fn probe(&self, data: &[u8]) -> u8;
}
Used to get a format descriptor and create a new demuxer.

Required Associated Types

type OutputDemuxer: Demuxer

The specific type of the demuxer.

Required Methods

fn create(&self) -> Self::OutputDemuxer

Creates a new demuxer for the requested format.

fn describe(&self) -> &Descr

Returns the descriptor of a format.

fn probe(&self, data: &[u8]) -> u8

Returns a score which represents how much the input data are associated to a format.

Implementors