Probe

Trait Probe 

pub trait Probe<T: Descriptor + ?Sized> {
    // Required method
    fn probe(&self, data: &[u8]) -> Option<&'static T>;
}
Used to define different ways to probe a format.

Required Methods

fn probe(&self, data: &[u8]) -> Option<&'static T>

Probes whether the input data is associated to a determined format.

Implementations on Foreign Types

Source

impl<T: Descriptor + ?Sized> Probe<T> for [&'static T]

Source

fn probe(&self, data: &[u8]) -> Option<&'static T>

Implementors