Context

Struct Context 

pub struct Context<M: Muxer + Send, W: Write> {
    pub user_private: Option<Box<dyn Any + Send + Sync>>,
    /* private fields */
}
Auxiliary structure to encapsulate a muxer object and its additional data.

Fields

user_private: Option<Box<dyn Any + Send + Sync>>

User private data.

This data cannot be cloned.

Implementations

Source

impl<M: Muxer, W: Write> Context<M, W>

pub fn new(muxer: M, writer: Writer<W>) -> Self

Creates a new Context instance.

pub fn configure(&mut self) -> Result<()>

Configures a muxer.

pub fn write_header(&mut self) -> Result<()>

Writes a stream header to an internal buffer and returns how many bytes were written or an error.

pub fn write_packet(&mut self, pkt: Arc<Packet>) -> Result<()>

Writes a stream packet to an internal buffer and returns how many bytes were written or an error.

pub fn write_trailer(&mut self) -> Result<()>

Writes a stream trailer to an internal buffer and returns how many bytes were written or an error.

pub fn set_global_info(&mut self, info: GlobalInfo) -> Result<()>

Sets global media file information for a muxer.

pub fn set_option<'a, V>(&mut self, key: &str, val: V) -> Result<()>
where V: Into<Value<'a>>,

Sets a muxer option.

This method should be called as many times as the number of options present in a muxer.

pub fn writer(&self) -> &Writer<W>

Returns the underlying writer.

pub fn into_writer(self) -> Writer<W>

Consumes this muxer and returns the underlying writer.