pub trait Probe<T: Descriptor + ?Sized> {
// Required method
fn probe(&self, data: &[u8]) -> Option<&'static T>;
}Expand description
Used to define different ways to probe a format.
Required Methods
Sourcefn probe(&self, data: &[u8]) -> Option<&'static T>
fn probe(&self, data: &[u8]) -> Option<&'static T>
Probes whether the input data is associated to a determined format.